@@ -95,6 +95,7 @@ typedef struct
     XfcePanelPlugin *plugin;
 
     GtkWidget        *ebox, *timechargebox, *actempbox;
+    GtkWidget        *timechargealignment, *actempalignment;
     GtkWidget        *battstatus;
     int            timeoutid;    /* To update apm status */
     int            method;
@@ -508,6 +509,7 @@ battmon.c:241: for each function it appears in.)
 
     if(battmon->options.display_percentage && charge > 0 && !(battmon->options.hide_when_full && acline && charge >= 99)){
         gtk_widget_show(GTK_WIDGET(battmon->charge));
+        gtk_widget_show(GTK_WIDGET(battmon->timechargealignment));
         g_snprintf(buffer, sizeof(buffer),"%d%% ", charge);
         gtk_label_set_text(battmon->charge,buffer);
     } else {
@@ -516,12 +518,16 @@ battmon.c:241: for each function it appears in.)
 
     if (battmon->options.display_time && time_remaining > 0 && !(battmon->options.hide_when_full && acline && charge >= 99 )){
         gtk_widget_show(GTK_WIDGET(battmon->rtime));
+        gtk_widget_show(GTK_WIDGET(battmon->timechargealignment));
         g_snprintf(buffer, sizeof(buffer),"%02d:%02d ",time_remaining/60,time_remaining%60);
         gtk_label_set_text(battmon->rtime,buffer);
 
     } else {
         gtk_widget_hide(GTK_WIDGET(battmon->rtime));
     }
+    if ((!battmon->options.display_time && !battmon->options.display_percentage) || (battmon->options.hide_when_full && acline && charge >= 99 )) {
+        gtk_widget_hide(GTK_WIDGET(battmon->timechargealignment));
+    }
 
 
     if(acline) {
@@ -553,6 +559,7 @@ battmon.c:241: for each function it appears in.)
     if(battmon->options.display_power){
       gtk_widget_show(GTK_WIDGET(battmon->acfan));
       gtk_widget_show(GTK_WIDGET(battmon->temp));
+      gtk_widget_show_all(GTK_WIDGET(battmon->actempalignment));
 
       fan=get_fan_status();
       if(acline && fan)
@@ -577,6 +584,7 @@ battmon.c:241: for each function it appears in.)
     } else {
       gtk_widget_hide(GTK_WIDGET(battmon->acfan));
       gtk_widget_hide(GTK_WIDGET(battmon->temp));
+      gtk_widget_hide(GTK_WIDGET(battmon->actempalignment));
     }
 
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(battmon->battstatus), NULL);
@@ -651,7 +659,6 @@ do_low_warn:
 
 static void setup_battmon(t_battmon *battmon)
 {
-    GtkWidget *alignment;
     GdkPixbuf *icon;
     gint size;
 
@@ -665,9 +672,11 @@ static void setup_battmon(t_battmon *battmon)
     battmon->battstatus = gtk_progress_bar_new();
 
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(battmon->battstatus), 0.0);
+    gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(battmon->battstatus),
+               (xfce_panel_plugin_get_orientation(battmon->plugin) == GTK_ORIENTATION_HORIZONTAL ? GTK_PROGRESS_BOTTOM_TO_TOP : GTK_PROGRESS_LEFT_TO_RIGHT));
 
     battmon->label = (GtkLabel *)gtk_label_new(_("Battery"));
-    gtk_box_pack_start(GTK_BOX(battmon->ebox),GTK_WIDGET(battmon->label),FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(battmon->ebox),GTK_WIDGET(battmon->label),FALSE, FALSE, 2);
 
     battmon->image = xfce_panel_image_new_from_source("xfce4-battery-plugin");
     xfce_panel_image_set_size(XFCE_PANEL_IMAGE(battmon->image), size);
@@ -682,23 +691,23 @@ static void setup_battmon(t_battmon *battmon)
     /* create the label hvbox with an orientation opposite to the panel */
     battmon->timechargebox = xfce_hvbox_new(!xfce_panel_plugin_get_orientation(battmon->plugin), FALSE, 0);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-    gtk_container_add (GTK_CONTAINER(alignment), battmon->timechargebox);
-    gtk_box_pack_start(GTK_BOX(battmon->ebox), alignment, FALSE, FALSE, 0);
+    battmon->timechargealignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+    gtk_container_add (GTK_CONTAINER(battmon->timechargealignment), battmon->timechargebox);
+    gtk_box_pack_start(GTK_BOX(battmon->ebox), battmon->timechargealignment, FALSE, FALSE, 2);
 
     battmon->charge = (GtkLabel *)gtk_label_new("50%%");
-    gtk_box_pack_start(GTK_BOX(battmon->timechargebox),GTK_WIDGET(battmon->charge),TRUE, TRUE, 2);
+    gtk_box_pack_start(GTK_BOX(battmon->timechargebox),GTK_WIDGET(battmon->charge),TRUE, TRUE, 0);
 
     battmon->rtime = (GtkLabel *)gtk_label_new("01:00");
-    gtk_box_pack_start(GTK_BOX(battmon->timechargebox),GTK_WIDGET(battmon->rtime),TRUE, TRUE, 2);
+    gtk_box_pack_start(GTK_BOX(battmon->timechargebox),GTK_WIDGET(battmon->rtime),TRUE, TRUE, 0);
 
     /* ac-fan-temp */
     /* create the label hvbox with an orientation opposite to the panel */
     battmon->actempbox = xfce_hvbox_new(!xfce_panel_plugin_get_orientation(battmon->plugin), FALSE, 0);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-    gtk_container_add (GTK_CONTAINER(alignment), battmon->actempbox);
-    gtk_box_pack_start(GTK_BOX(battmon->ebox), alignment, FALSE, FALSE, 0);
+    battmon->actempalignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+    gtk_container_add (GTK_CONTAINER(battmon->actempalignment), battmon->actempbox);
+    gtk_box_pack_start(GTK_BOX(battmon->ebox), battmon->actempalignment, FALSE, FALSE, 2);
 
     battmon->acfan = (GtkLabel *)gtk_label_new("AC FAN");
     gtk_box_pack_start(GTK_BOX(battmon->actempbox),GTK_WIDGET(battmon->acfan),TRUE, TRUE, 0);
@@ -714,6 +723,7 @@ static void setup_battmon(t_battmon *battmon)
     if(!battmon->options.display_power){
         gtk_widget_hide(GTK_WIDGET(battmon->acfan));
         gtk_widget_hide(GTK_WIDGET(battmon->temp));
+        gtk_widget_hide(GTK_WIDGET(battmon->actempalignment));
     }
     if(!battmon->options.display_percentage){
         gtk_widget_hide(GTK_WIDGET(battmon->charge));
@@ -721,7 +731,9 @@ static void setup_battmon(t_battmon *battmon)
     if (!battmon->options.display_time){
         gtk_widget_hide(GTK_WIDGET(battmon->rtime));
     }
-
+    if (!battmon->options.display_time && !battmon->options.display_percentage) {
+        gtk_widget_hide(GTK_WIDGET(battmon->timechargealignment));
+    }
     gtk_widget_show(battmon->ebox);
 
     battmon->battstatus_style = gtk_widget_get_modifier_style(battmon->battstatus);
@@ -788,7 +800,6 @@ battmon_set_orientation (XfcePanelPlugin *plugin, GtkOrientation orientation,
     xfce_hvbox_set_orientation(XFCE_HVBOX(battmon->actempbox), !orientation);
     gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(battmon->battstatus),
                (orientation == GTK_ORIENTATION_HORIZONTAL ? GTK_PROGRESS_BOTTOM_TO_TOP : GTK_PROGRESS_LEFT_TO_RIGHT));
-    battmon_set_labels_orientation(battmon, orientation);
     battmon_set_size(plugin, xfce_panel_plugin_get_size (plugin), battmon);
     update_apm_status( battmon );
     battmon->timeoutid = g_timeout_add(1 * 1024, (GSourceFunc) update_apm_status, battmon);
@@ -974,9 +985,11 @@ battmon_write_config(XfcePanelPlugin *plugin, t_battmon *battmon)
 static gboolean
 battmon_set_size(XfcePanelPlugin *plugin, int size, t_battmon *battmon)
 {
+    int border_width;
 #ifdef HAS_PANEL_49
     size /= xfce_panel_plugin_get_nrows (battmon->plugin);
 #endif
+    border_width = size > 26 ? 2 : 1;
     DBG("set_size(%d)", size);
     if (xfce_panel_plugin_get_orientation(plugin) == GTK_ORIENTATION_HORIZONTAL)
     {
@@ -985,7 +998,7 @@ battmon_set_size(XfcePanelPlugin *plugin, int size, t_battmon *battmon)
                                 -1, size);
         /* size of the progressbar */
         gtk_widget_set_size_request(GTK_WIDGET(battmon->battstatus),
-                BORDER, size);
+                8, -1);
     }
     else
     {
@@ -994,12 +1007,12 @@ battmon_set_size(XfcePanelPlugin *plugin, int size, t_battmon *battmon)
                 size, -1);
         /* size of the progressbar */
         gtk_widget_set_size_request(GTK_WIDGET(battmon->battstatus),
-                size, BORDER);
+                -1, 8);
     }
 
-    gtk_container_set_border_width (GTK_CONTAINER (battmon->ebox), (size > 26 ? 2 : 0));
+    gtk_container_set_border_width (GTK_CONTAINER (battmon->ebox), border_width);
     /* update the icon */
-    xfce_panel_image_set_size(XFCE_PANEL_IMAGE(battmon->image), size);
+    xfce_panel_image_set_size(XFCE_PANEL_IMAGE(battmon->image), size - (2 * border_width));
     return TRUE;
 }
 
