@@ -30,6 +30,16 @@
 #include <dirent.h>
 #include <glob.h>
 
+#ifdef __FreeBSD__
+#include <fcntl.h>
+#include <sys/ioctl.h>
+#include <dev/acpica/acpiio.h>
+#define ACPIDEV         "/dev/acpi"
+static int      acpifd;
+#define UNKNOWN_CAP 0xffffffff
+#define UNKNOWN_VOLTAGE 0xffffffff
+#endif
+
 #if HAVE_SYSCTL
 
 #if defined(__NetBSD__) || defined (__OpenBSD__)
@@ -730,6 +740,24 @@ int read_acpi_info(int battery)
 #endif
   }
   acpiinfo->present = retval;
+
+#ifdef __FreeBSD__
+  union acpi_battery_ioctl_arg battio;
+  acpifd = open(ACPIDEV, O_RDONLY);
+
+  battio.unit = battery;
+  if (ioctl(acpifd, ACPIIO_BATT_GET_BIF, &battio) == -1) {
+	  return 0;
+  }
+  close(acpifd);
+
+  acpiinfo->design_capacity = battio.bif.dcap;
+  acpiinfo->last_full_capacity = battio.bif.lfcap;
+  acpiinfo->battery_technology = battio.bif.btech;
+  acpiinfo->design_voltage = battio.bif.dvol;
+  acpiinfo->design_capacity_warning = battio.bif.wcap;
+  acpiinfo->design_capacity_low = battio.bif.lcap;
+#endif
   return 1;
 #else
   return 0;
@@ -787,7 +815,7 @@ int read_acpi_state_sysfs(int battery)
 			acpistate->rcapacity = read_sysfs_int(buf);
 			acpistate->percentage = (((float) acpistate->rcapacity)/acpiinfo->last_full_capacity) * 100;
 		}
-		if (strcmp(name,"current_now") == 0)
+		if ((strcmp(name,"current_now") == 0) || (strcmp(name,"power_now") == 0))
 		{
 			sprintf(buf,"%s/%s",batteries[battery], name);
 			acpistate->prate = read_sysfs_int(buf);
@@ -966,6 +994,29 @@ int read_acpi_state(int battery)
 #endif
   }
   acpistate->percentage =retval;
+
+#ifdef __FreeBSD__
+  union acpi_battery_ioctl_arg battio;
+  acpifd = open(ACPIDEV, O_RDONLY);
+
+  battio.unit = battery;
+  if (ioctl(acpifd, ACPIIO_BATT_GET_BATTINFO, &battio) == -1) {
+	  return 0;
+  }
+
+  acpistate->state = battio.battinfo.state;
+  acpistate->prate = battio.battinfo.rate;
+  acpistate->rcapacity = acpiinfo->last_full_capacity * battio.battinfo.cap / 100;
+  acpistate->rtime = battio.battinfo.min;
+  acpistate->percentage = battio.battinfo.cap;
+
+  battio.unit = battery;
+  if (ioctl(acpifd, ACPIIO_BATT_GET_BATTINFO, &battio) == -1) {
+	  return 0;
+  }
+  close(acpifd);
+  acpistate->pvoltage = battio.bst.volt;
+#endif
   return 1;
 #else
   return 0;
@@ -1002,18 +1053,36 @@ const char *get_temperature(void)
 #ifdef __linux__
   FILE *fp;
   char *proc_temperature="/proc/acpi/thermal_zone/*/temperature";
-  static char *p,line[256];
+  char *sys_temperature="/sys/class/thermal/thermal_zone*/temp";
+  static char *p,*p2,line[256];
 
-  if ( (fp=fopen_glob(proc_temperature, "r")) == NULL) return NULL;
-  fgets(line,255,fp);
-  fclose(fp);
-  p=strtok(line," ");
-  if (!p) return NULL;
-  p=p+strlen(p)+1;
-  while (p && *p ==' ') p++;
-  if (*p==0) return NULL;
-  if (strchr(p,'\n')) p=strtok(p,"\n");
-  return (const char *)p;
+  if ( (fp=fopen_glob(proc_temperature, "r")) != NULL )
+  {
+    fgets(line,255,fp);
+    fclose(fp);
+    p=strtok(line," ");
+    if (!p) return NULL;
+    p=p+strlen(p)+1;
+    while (p && *p ==' ') p++;
+    if (*p==0) return NULL;
+    if (strchr(p,'\n')) p=strtok(p,"\n");
+    return (const char *)p;
+  }
+  else if ( (fp=fopen_glob(sys_temperature, "r")) != NULL )
+  {
+    fgets(line,255,fp);
+    fclose(fp);
+    p = line;
+    if (strchr(p,'\n')) *strchr(p,'\n') = 0;
+    if (strlen(p) <= 3) return NULL;
+    p2 = p + strlen(p) - 3;
+    strcpy(p2, " C");
+    return (const char *)p;
+  }
+  else
+  {
+    return NULL;
+  }
 #else
 #ifdef HAVE_SYSCTL
   static char buf[BUFSIZ];
